/**
 */
#include <Arduino.h>
#include <SPI.h>
//#include <WiFi101.h>
#include <Thing.h>
#include <WebThingAdapter.h>
#include <OneWire.h>
#include <DallasTemperature.h>
#include <Wire.h>

#ifndef PIN_STATE_HIGH
#define PIN_STATE_HIGH HIGH
#endif
#ifndef PIN_STATE_LOW
#define PIN_STATE_LOW LOW
#endif

#define LED_BUILTIN 2

// Data wire is plugged into digital pin 2 on the Arduino
#define D2 4
#define ONE_WIRE_BUS 4

int deviceCount = 0;
float temp;
float temp2;

// Setup a oneWire instance to communicate with any OneWire device
OneWire oneWire(ONE_WIRE_BUS);  

// Pass oneWire reference to DallasTemperature library
DallasTemperature sensors(&oneWire);

WebThingAdapter *adapter;

const char *sensorTypes[] = {"TemperatureSensor", nullptr};
ThingDevice weather("ds18b20", "ds18b20 Weather Sensor", sensorTypes);
ThingProperty weatherTemp("temperature", "", NUMBER, "TemperatureProperty");
ThingProperty weatherTemp2("temperature2", "", NUMBER, "TemperatureProperty");

const char* ssid = "";
const char* password = "";

// Hostname used by mDNS
const String mDNSHostname = "tempsensor";

void setup() {
  sensors.begin();
  Serial.begin(9600);
  Serial.print("Locating devices...");
  Serial.print("Found ");
  deviceCount = sensors.getDeviceCount();
  Serial.print(deviceCount, DEC);
  Serial.println(" devices.");
  Serial.println("");

  // Connect to WiFi access point
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  while ( WiFi.status() != WL_CONNECTED ) {
    delay(500);
    Serial.print(".");
  }

// configure the LED pin for output mode
  pinMode(LED_BUILTIN, OUTPUT);
  // blink the led to show an unconnected status
  digitalWrite(LED_BUILTIN, PIN_STATE_HIGH);
  delay(500);
  digitalWrite(LED_BUILTIN, PIN_STATE_LOW);
  delay(500);

  Wire.begin();

  Serial.println();

  // Show connection details
  Serial.println("Connected!");
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());

  // connected, make the LED stay on
  digitalWrite(LED_BUILTIN, PIN_STATE_HIGH);
  // Create new WebThings connection handle (default port: 80)
  adapter = new WebThingAdapter("weathersensor", WiFi.localIP());

  weatherTemp.unit = "celsius";
  weatherTemp2.unit = "celsius";

  weather.addProperty(&weatherTemp);
  weather.addProperty(&weatherTemp2);
  adapter->addDevice(&weather);
  adapter->begin(); 
  // Start mDNS and HTTP server
  Serial.println("HTTP server started");
  Serial.print("http://");
  Serial.print(WiFi.localIP());
  Serial.print("/things/");
  //Serial.print(sensor.id);
}

unsigned int auxCounterTick = 0;

void loop() {
  // Update all properties and events over the connection
  adapter->update();
  
  auxCounterTick++;

   float temp(NAN), temp2(NAN);
  //BME280::TempUnit tempUnit(BME280::TempUnit_Celsius);
  //bme.read(pres, temp, hum, tempUnit, presUnit);

   // Send command to all the sensors for temperature conversion
  sensors.requestTemperatures(); 
  
  ThingPropertyValue value;
  ThingPropertyValue value2;
  // Display temperature from each sensor
  for (int i = 0;  i < deviceCount;  i++)
  {
    //Serial.print("Sensor ");
    //Serial.print(i+1);
    //Serial.print(" : ");
    
    //tempC = sensors.getTempCByIndex(i);

    temp = sensors.getTempCByIndex(0);
    temp2 = sensors.getTempCByIndex(1);

    value.number = temp;
    weatherTemp.setValue(value);
    value2.number = temp2;
    weatherTemp2.setValue(value2);

    Serial.print(temp);
    Serial.print(" ");
    Serial.println(temp2);
    //Serial.print((char)176);//shows degrees character
    //Serial.print(" degC  |  ");
    //Serial. print('\n');

    //Serial.print("-----> Control meesage: ");
    //Serial.println(auxCounterTick);

  // Do nothing for a bit
  delay(1000);
}}
